
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

( cd usr/doc/OpenJDK17-17.0.16 ; rm -rf legal )
( cd usr/doc/OpenJDK17-17.0.16 ; ln -sf ../../lib64/OpenJDK17-17.0.16/legal legal )
( cd usr/doc/OpenJDK17-17.0.16 ; rm -rf release )
( cd usr/doc/OpenJDK17-17.0.16 ; ln -sf ../../lib64/OpenJDK17-17.0.16/release release )
( cd usr/lib64 ; rm -rf OpenJDK17-17.0.16 )
( cd usr/lib64 ; ln -sf java OpenJDK17-17.0.16 )
( cd usr/lib64/java/legal/java.compiler ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.compiler ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.compiler ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.compiler ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.compiler ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.compiler ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.datatransfer ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.datatransfer ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.datatransfer ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.datatransfer ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.datatransfer ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.datatransfer ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.desktop ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.desktop ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.desktop ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.desktop ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.desktop ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.desktop ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.instrument ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.instrument ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.instrument ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.instrument ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.instrument ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.instrument ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.logging ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.logging ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.logging ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.logging ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.logging ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.logging ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.management.rmi ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.management.rmi ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.management.rmi ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.management.rmi ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.management.rmi ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.management.rmi ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.management ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.management ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.management ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.management ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.management ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.management ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.naming ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.naming ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.naming ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.naming ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.naming ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.naming ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.net.http ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.net.http ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.net.http ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.net.http ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.net.http ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.net.http ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.prefs ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.prefs ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.prefs ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.prefs ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.prefs ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.prefs ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.rmi ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.rmi ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.rmi ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.rmi ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.rmi ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.rmi ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.scripting ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.scripting ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.scripting ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.scripting ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.scripting ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.scripting ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.se ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.se ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.se ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.se ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.se ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.se ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.security.jgss ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.security.jgss ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.security.jgss ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.security.jgss ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.security.jgss ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.security.jgss ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.security.sasl ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.security.sasl ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.security.sasl ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.security.sasl ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.security.sasl ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.security.sasl ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.smartcardio ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.smartcardio ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.smartcardio ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.smartcardio ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.smartcardio ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.smartcardio ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.sql.rowset ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.sql.rowset ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.sql.rowset ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.sql.rowset ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.sql.rowset ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.sql.rowset ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.sql ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.sql ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.sql ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.sql ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.sql ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.sql ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.transaction.xa ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.transaction.xa ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.transaction.xa ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.transaction.xa ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.transaction.xa ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.transaction.xa ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.xml.crypto ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.xml.crypto ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.xml.crypto ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.xml.crypto ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.xml.crypto ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.xml.crypto ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/java.xml ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.xml ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/java.xml ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.xml ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/java.xml ; rm -rf LICENSE )
( cd usr/lib64/java/legal/java.xml ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.accessibility ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.accessibility ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.accessibility ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.accessibility ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.accessibility ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.accessibility ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.attach ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.attach ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.attach ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.attach ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.attach ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.attach ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.charsets ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.charsets ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.charsets ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.charsets ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.charsets ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.charsets ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.compiler ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.compiler ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.compiler ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.compiler ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.compiler ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.compiler ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.crypto.cryptoki ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.crypto.cryptoki ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.crypto.cryptoki ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.crypto.cryptoki ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.crypto.cryptoki ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.crypto.cryptoki ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.crypto.ec ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.crypto.ec ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.crypto.ec ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.crypto.ec ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.crypto.ec ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.crypto.ec ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.dynalink ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.dynalink ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.dynalink ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.dynalink ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.dynalink ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.dynalink ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.editpad ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.editpad ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.editpad ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.editpad ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.editpad ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.editpad ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.hotspot.agent ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.hotspot.agent ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.hotspot.agent ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.hotspot.agent ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.hotspot.agent ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.hotspot.agent ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.httpserver ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.httpserver ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.httpserver ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.httpserver ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.httpserver ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.httpserver ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.incubator.foreign ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.incubator.foreign ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.incubator.foreign ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.incubator.foreign ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.incubator.foreign ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.incubator.foreign ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.incubator.vector ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.incubator.vector ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.incubator.vector ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.incubator.vector ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.incubator.vector ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.incubator.vector ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.ed ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.ed ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.ed ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.ed ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.ed ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.ed ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.jvmstat ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.jvmstat ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.jvmstat ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.jvmstat ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.jvmstat ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.jvmstat ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.le ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.le ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.le ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.le ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.le ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.le ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.opt ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.opt ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.opt ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.opt ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.opt ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.opt ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.vm.ci ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.vm.ci ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.vm.ci ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.vm.ci ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.vm.ci ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.vm.ci ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler.management ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler.management ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler.management ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler.management ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler.management ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler.management ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.internal.vm.compiler ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jartool ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jartool ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jartool ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jartool ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jartool ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jartool ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.javadoc ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.javadoc ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.javadoc ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.javadoc ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.javadoc ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.javadoc ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jcmd ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jcmd ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jcmd ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jcmd ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jcmd ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jcmd ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jconsole ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jconsole ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jconsole ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jconsole ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jconsole ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jconsole ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jdeps ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jdeps ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jdeps ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jdeps ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jdeps ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jdeps ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jdi ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jdi ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jdi ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jdi ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jdi ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jdi ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jdwp.agent ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jdwp.agent ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jdwp.agent ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jdwp.agent ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jdwp.agent ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jdwp.agent ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jfr ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jfr ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jfr ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jfr ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jfr ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jfr ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jlink ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jlink ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jlink ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jlink ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jlink ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jlink ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jpackage ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jpackage ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jpackage ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jpackage ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jpackage ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jpackage ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jshell ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jshell ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jshell ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jshell ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jshell ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jshell ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jsobject ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jsobject ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jsobject ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jsobject ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jsobject ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jsobject ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.jstatd ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jstatd ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.jstatd ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jstatd ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.jstatd ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.jstatd ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.localedata ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.localedata ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.localedata ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.localedata ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.localedata ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.localedata ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.localedata ; rm -rf cldr.md )
( cd usr/lib64/java/legal/jdk.localedata ; ln -sf ../java.base/cldr.md cldr.md )
( cd usr/lib64/java/legal/jdk.management.agent ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.management.agent ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.management.agent ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.management.agent ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.management.agent ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.management.agent ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.management.jfr ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.management.jfr ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.management.jfr ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.management.jfr ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.management.jfr ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.management.jfr ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.management ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.management ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.management ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.management ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.management ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.management ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.naming.dns ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.naming.dns ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.naming.dns ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.naming.dns ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.naming.dns ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.naming.dns ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.naming.rmi ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.naming.rmi ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.naming.rmi ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.naming.rmi ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.naming.rmi ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.naming.rmi ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.net ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.net ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.net ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.net ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.net ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.net ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.nio.mapmode ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.nio.mapmode ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.nio.mapmode ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.nio.mapmode ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.nio.mapmode ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.nio.mapmode ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.random ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.random ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.random ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.random ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.random ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.random ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.sctp ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.sctp ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.sctp ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.sctp ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.sctp ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.sctp ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.security.auth ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.security.auth ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.security.auth ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.security.auth ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.security.auth ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.security.auth ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.security.jgss ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.security.jgss ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.security.jgss ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.security.jgss ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.security.jgss ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.security.jgss ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.unsupported.desktop ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.unsupported.desktop ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.unsupported.desktop ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.unsupported.desktop ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.unsupported.desktop ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.unsupported.desktop ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.unsupported ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.unsupported ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.unsupported ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.unsupported ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.unsupported ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.unsupported ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.xml.dom ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.xml.dom ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.xml.dom ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.xml.dom ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.xml.dom ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.xml.dom ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64/java/legal/jdk.zipfs ; rm -rf ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.zipfs ; ln -sf ../java.base/ADDITIONAL_LICENSE_INFO ADDITIONAL_LICENSE_INFO )
( cd usr/lib64/java/legal/jdk.zipfs ; rm -rf ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.zipfs ; ln -sf ../java.base/ASSEMBLY_EXCEPTION ASSEMBLY_EXCEPTION )
( cd usr/lib64/java/legal/jdk.zipfs ; rm -rf LICENSE )
( cd usr/lib64/java/legal/jdk.zipfs ; ln -sf ../java.base/LICENSE LICENSE )
( cd usr/lib64 ; rm -rf libawt.so )
( cd usr/lib64 ; ln -sf java/lib/libawt.so libawt.so )
( cd usr/lib64 ; rm -rf libawt_xawt.so )
( cd usr/lib64 ; ln -sf java/lib/libawt_xawt.so libawt_xawt.so )
( cd usr/lib64 ; rm -rf libjava.so )
( cd usr/lib64 ; ln -sf java/lib/libjava.so libjava.so )
( cd usr/lib64 ; rm -rf libjawt.so )
( cd usr/lib64 ; ln -sf java/lib/libjawt.so libjawt.so )
( cd usr/lib64 ; rm -rf libjvm.so )
( cd usr/lib64 ; ln -sf java/lib/server/libjvm.so libjvm.so )
( cd usr/lib64 ; rm -rf libverify.so )
( cd usr/lib64 ; ln -sf java/lib/libverify.so libverify.so )
